@@ -5,17 +5,13 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 6026 $";
-#endif
-
-/* $Id: hblocks.c 6026 2014-01-16 15:16:16Z bmribler $ */
+/* $Id$ */
 
 /*LINTLIBRARY */
 /* ------------------------------ hblocks.c -------------------------------
@@ -1754,20 +1750,23 @@ HLPendaccess(accrec_t * access_rec)
     filerec_t  *file_rec;           /* file record */
     intn      ret_value = SUCCEED;
 
+    /* validate argument */
+    if (access_rec == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
     /* convert file id to file record */
     file_rec = HAatom_object(access_rec->file_id);
+    if (BADFREC(file_rec))
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* detach the special information record.
        If no more references to that, free the record */
-    HLPcloseAID(access_rec);
+    if (HLPcloseAID(access_rec) == FAIL)
+        HGOTO_ERROR(DFE_CANTCLOSE, FAIL);
 
     /* update file and access records */
     if (HTPendaccess(access_rec->ddid) == FAIL)
-      HGOTO_ERROR(DFE_CANTFLUSH, FAIL);
-
-    /* validate file record */
-    if (BADFREC(file_rec))
-        HGOTO_ERROR(DFE_INTERNAL, FAIL);
+      HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
 
     /* detach from the file */
     file_rec->attach--;
@@ -1778,7 +1777,8 @@ HLPendaccess(accrec_t * access_rec)
 done:
   if(ret_value == FAIL)   
     { /* Error condition cleanup */
-
+      if(access_rec!=NULL)
+          HIrelease_accrec_node(access_rec);
     } /* end if */
 
   /* Normal function cleanup */
