@@ -5,17 +5,13 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 5887 $";
-#endif
-
-/* $Id: hcomp.c 5887 2012-10-08 04:57:47Z bmribler $ */
+/* $Id$ */
 
 /*
 FILE
@@ -1547,19 +1543,22 @@ HCPendaccess(accrec_t * access_rec)
     filerec_t  *file_rec;           /* file record */
     intn      ret_value = SUCCEED;
 
+    /* validate argument */
+    if (access_rec == NULL)
+        HGOTO_ERROR(DFE_ARGS, FAIL);
+
     /* convert file id to file record */
     file_rec = HAatom_object(access_rec->file_id);
-
-    /* validate file record */
     if (BADFREC(file_rec))
-        HGOTO_ERROR(DFE_INTERNAL, FAIL);
+        HGOTO_ERROR(DFE_ARGS, FAIL);
 
     /* close the file pointed to by this access rec */
-    HCPcloseAID(access_rec);
+    if (HCPcloseAID(access_rec) == FAIL)
+        HGOTO_ERROR(DFE_CANTCLOSE, FAIL);
 
     /* update file and access records */
     if (HTPendaccess(access_rec->ddid) == FAIL)
-      HGOTO_ERROR(DFE_CANTFLUSH, FAIL);
+      HGOTO_ERROR(DFE_CANTENDACCESS, FAIL);
 
     /* detach from the file */
     file_rec->attach--;
@@ -1570,7 +1569,8 @@ HCPendaccess(accrec_t * access_rec)
 done:
   if(ret_value == FAIL)   
     { /* Error condition cleanup */
-
+      if(access_rec!=NULL)
+          HIrelease_accrec_node(access_rec);
     } /* end if */
 
   /* Normal function cleanup */
@@ -1980,8 +1980,8 @@ HCPgetdatasize(int32 file_id,
 		  HGOTO_ERROR(DFE_INTERNAL, FAIL);
 	    }
 
-	    /* unlimited dimension falls in here */
-	    else if (sp_tag == SPECIAL_LINKED)
+	    /* unlimited dimension and external data fall in here */
+	    else if (sp_tag == SPECIAL_LINKED || sp_tag == SPECIAL_EXT)
 	    {
 		INT32DECODE(p, len);	/* get total data length */
 		*orig_size = *comp_size = len;	/* set data sizes */
